@@ -10,8 +10,9 @@ from avatar_utils.objects.abstracts.abstract_object import AbstractObject
 class Tag(AbstractObject):
     service: str = None
     category: str = None
-    text: str = None
+    name: str = None
     created_at: str = None
+    updated_at: str = None
     approved_at: str = None
 
     repr_type: str = None
