@@ -5,7 +5,7 @@ from unittest import TestCase
 import flask
 import requests
 
-from avatar_utils.tests.Env import DevEnv
+from avatar_utils.tests.Env import *
 
 logger = logging.getLogger(__name__)
 
